@@ -13,13 +13,18 @@
 //! # }
 //! ```
 
+use primitive_types::U256;
 use proc_macro::TokenStream;
 use syn::{parse_macro_input, LitInt};
-use primitive_types::U256;
 
 #[proc_macro]
 pub fn u256(input: TokenStream) -> TokenStream {
     let input = parse_macro_input!(input as LitInt);
     let number = U256::from_dec_str(input.base10_digits()).expect("the number can't fit into U256");
-    format!("primitive_types::U256([{}u64, {}u64, {}u64, {}u64])", number.0[0], number.0[1], number.0[2], number.0[3]).parse().unwrap()
+    format!(
+        "primitive_types::U256([{}u64, {}u64, {}u64, {}u64])",
+        number.0[0], number.0[1], number.0[2], number.0[3]
+    )
+    .parse()
+    .unwrap()
 }
